import asyncio
from typing import Dict, Any
from spider_rs import Website

async def main() -> None:
    website: Website = (
        Website("https://choosealicense.com", False)
        .with_screenshot({
            "params": {
                "cdp_params": {
                    "format": None,
                    "quality": None,
                    "clip": None,
                    "from_surface": None,
                    "capture_beyond_viewport": None
                },
                "full_page": True,
                "omit_background": False
            },
            "bytes": False,
            "save": True,
            "output_dir": None
        })
    )
    website.crawl(None, None, True)
    print(website.get_links())

asyncio.run(main())



import asyncio
from typing import Any
from spider_rs import Website

class Subscription:
    def __init__(self) -> None:
        print("Subscription Created...")
    
    def __call__(self, page: Any) -> None:
        print(f"{page.url} - status: {page.status_code}")
        # if (website.size >= 100):
        #     website.stop()

async def main() -> None:
    website: Website = Website("https://www.drake.com")
    website.crawl(Subscription())

asyncio.run(main())



import time, scrapy, sys
from scrapy.linkextractors import LinkExtractor
from scrapy.spiders import CrawlSpider, Rule
from scrapy.crawler import CrawlerProcess
from urllib.parse import urlparse
from scrapy.settings import Settings
from scrapy.http import Response
from typing import List, Type, Union, ClassVar

url: str = len(sys.argv) > 1 and str(sys.argv[1]) or "https://rsseau.fr"
host: str = urlparse(url).hostname

class MySpider(CrawlSpider):
    name: Union[str, None] = host
    allowed_domains: List[str] = [host]
    start_urls: List[str] = [url]
    links: List[str] = []
    rules: ClassVar[tuple] = (
        Rule(LinkExtractor(), callback='parse_item', follow=True),
    )

    @classmethod
    def update_settings(cls: Type['MySpider'], settings: Settings) -> None:
        super().update_settings(settings)
        settings.set("LOG_ENABLED", "false", priority="spider")

    def parse_item(self, response: Response) -> None:
        self.links.append(response.url)

print("benching scrappy(python)...")
process: CrawlerProcess = CrawlerProcess()
spider: Type[MySpider] = MySpider
start: float = time.time()
process.crawl(spider)
process.start()
end: float = time.time()
print(url, "pages found " + str(len(spider.links)), "elapsed duration " + str(end - start) + "s", sep="\n")
